==> pochy-0.1.8-src.tar.gz: pochy-0.1.8-src/FolderView.h <==
#if !defined(AFX_MOOTREEVIEW_H__B0C245D4_42EA_11D5_B88C_00008659960F__INCLUDED_)
#define AFX_MOOTREEVIEW_H__B0C245D4_42EA_11D5_B88C_00008659960F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// FolderView.h : wb_[ t@C
//
#include <afxcview.h>
#include "BitmapTreeView.h"

#define FV_INBOX	(1)
#define FV_OUTBOX	(2)
#define FV_DRAFT	(3)
#define FV_TRASH	(4)
#define FV_TOP		(5)
#define FV_OTHER	(0)

/////////////////////////////////////////////////////////////////////////////
// CFolderView r[

class CFolderView : public CBitmapTreeView
{
protected:
	CFolderView();           // IɎgpveNg RXgN^
	DECLARE_DYNCREATE(CFolderView)

// Agr[g
public:
	CImageList m_image;
	CImageList* m_pDragImage;
	CImageList m_drag_image;
	BOOL m_bLDragging;
	HTREEITEM m_hitemDrag,m_hitemDrop;
	int m_ListItemDrag;
	CString m_current_edit_item_name;

// Iy[V
public:
	bool GetShowUnreadCount();
	void SetShowUnreadCount(bool bShowUnreadCount);
	BOOL AddFolder(HTREEITEM parent_ti);
	BOOL DeleteFolder(HTREEITEM ti);
	int GetSelectedItemKind();
	int WhatKind(HTREEITEM hItem);
	CString GetSelectedItemName();
	CString GetTopItemName(HTREEITEM ti);
	CString GetItemPath(HTREEITEM ti);
	void AddSubItem(HTREEITEM Item);
	void ConstructTree(CString account);
	void RefreshTree();
	void AddUser(CString path, CString user);
	void RemoveUser(CString user);
	void RenameUser(CString oldname, CString newname);

	HTREEITEM CopyItem(HTREEITEM hItem, HTREEITEM htiNewParent, HTREEITEM htiAfter = TVI_LAST );
	HTREEITEM CopyBranch(HTREEITEM htiBranch, HTREEITEM htiNewParent, HTREEITEM htiAfter = TVI_LAST);

protected:
	virtual void OnItemCopied(HTREEITEM hItem, HTREEITEM hNewItem);

protected:

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B

	//{{AFX_VIRTUAL(CFolderView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CFolderView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CFolderView)
	afx_msg void OnSelchanged(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnItemexpanded(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnSelchanging(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnSetFocus(CWnd* pOldWnd);
	afx_msg void OnBegindrag(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnMouseMove(UINT nFlags, CPoint point);
	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
	afx_msg void OnRclick(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnPopupDel();
	afx_msg void OnEndlabeledit(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnPopupRename();
	afx_msg void OnPopupAdd();
	afx_msg void OnBeginlabeledit(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnPopupRebuild();
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnPopupClearTrash();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
private:
	bool m_bShowUnreadCount;
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MOOTREEVIEW_H__B0C245D4_42EA_11D5_B88C_00008659960F__INCLUDED_)

==> pochy-0.2-src.tar.gz: pochy-0.2-src/FolderView.h <==
#if !defined(AFX_MOOTREEVIEW_H__B0C245D4_42EA_11D5_B88C_00008659960F__INCLUDED_)
#define AFX_MOOTREEVIEW_H__B0C245D4_42EA_11D5_B88C_00008659960F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// FolderView.h : wb_[ t@C
//
#include <afxcview.h>
#include "BitmapTreeView.h"

#define FV_INBOX	(1)
#define FV_OUTBOX	(2)
#define FV_DRAFT	(3)
#define FV_TRASH	(4)
#define FV_TOP		(5)
#define FV_OTHER	(0)

/////////////////////////////////////////////////////////////////////////////
// CFolderView r[

class CFolderView : public CBitmapTreeView
{
protected:
	CFolderView();           // IɎgpveNg RXgN^
	DECLARE_DYNCREATE(CFolderView)

// Agr[g
public:
	CImageList m_image;
	CImageList* m_pDragImage;
	CImageList m_drag_image;
	BOOL m_bLDragging;
	HTREEITEM m_hitemDrag,m_hitemDrop;
	int m_ListItemDrag;
	CString m_current_edit_item_name;

// Iy[V
public:
	int GetCurrentItemKind();
	void SelectFolder(const std::string& path);
	bool GetShowUnreadCount();
	void SetShowUnreadCount(bool bShowUnreadCount);
	BOOL AddFolder(HTREEITEM parent_ti);
	BOOL DeleteFolder(HTREEITEM ti);
	int GetSelectedItemKind();
	int WhatKind(HTREEITEM hItem);
	CString GetSelectedItemName();
	CString GetTopItemName(HTREEITEM ti);
	CString GetItemPath(HTREEITEM ti);
	void AddSubItem(HTREEITEM Item);
	void ConstructTree(CString account);
	void RefreshTree();
	void AddUser(CString path, CString user);
	void RemoveUser(CString user);
	void RenameUser(CString oldname, CString newname);

	HTREEITEM CopyItem(HTREEITEM hItem, HTREEITEM htiNewParent, HTREEITEM htiAfter = TVI_LAST );
	HTREEITEM CopyBranch(HTREEITEM htiBranch, HTREEITEM htiNewParent, HTREEITEM htiAfter = TVI_LAST);

protected:
	virtual void OnItemCopied(HTREEITEM hItem, HTREEITEM hNewItem);

protected:

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B

	//{{AFX_VIRTUAL(CFolderView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CFolderView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CFolderView)
	afx_msg void OnSelchanged(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnItemexpanded(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnSelchanging(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnSetFocus(CWnd* pOldWnd);
	afx_msg void OnBegindrag(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnMouseMove(UINT nFlags, CPoint point);
	afx_msg void OnLButtonUp(UINT nFlags, CPoint point);
	afx_msg void OnRclick(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnPopupDel();
	afx_msg void OnEndlabeledit(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnPopupRename();
	afx_msg void OnPopupAdd();
	afx_msg void OnBeginlabeledit(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnPopupRebuild();
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnPopupClearTrash();
	afx_msg void OnNextFolder();
	afx_msg void OnPrevFolder();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
private:
	HTREEITEM FindFolder(HTREEITEM hTreeItem, const std::string& path);
	bool m_bShowUnreadCount;
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MOOTREEVIEW_H__B0C245D4_42EA_11D5_B88C_00008659960F__INCLUDED_)
